:mod:`pyramid_authsanity.interfaces`
====================================

.. automodule:: pyramid_authsanity.interfaces

SourceService
-------------

.. autointerface:: IAuthSourceService 
    :members:

AuthService
-----------

.. autointerface:: IAuthService
    :members:
